package com.link.core.mvc.aop;

import com.link.base.user.model.CoreUser;
import com.link.core.basic.interceptors.mybatis.annotation.LinkOauthConditionV1;
import com.link.core.basic.interceptors.mybatis.annotation.LinkOauthConditionV2;
import com.link.core.basic.interceptors.mybatis.enumeration.HighestOauthType;
import com.link.core.basic.interceptors.mybatis.handle.select.SecurityMenuParse;
import com.link.core.basic.interceptors.mybatis.utils.HigestOauthUtil;
import com.link.core.basic.model.BasicModel;
import com.link.core.basic.query.QueryParams;
import com.link.core.basic.service.BasicServiceException;
import com.link.core.mvc.annotation.LinkApiHighestOauth;
import com.link.core.util.PropertyUtil;
import com.link.core.util.ReflectUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.UserUtil;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import javax.servlet.http.HttpServletRequest;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;

@Aspect
public class LinkApiHighestOauthCheckAspect {
   private static final Logger logger = LogManager.getLogger(LinkApiHighestOauthCheckAspect.class);
   private static final Set<String> DEFAULT_INTERCEPT_API = (Set)Stream.of("queryByExamplePage", "queryAll", "queryFieldsByExamplePage", "exportData", "streamExport").collect(Collectors.toCollection(HashSet::new));

   @Pointcut("execution(* com.link..controller..*.*(..))")
   private void processCtrllerPointcut() {
   }

   @Around("processCtrllerPointcut()")
   public Object doPointcut(ProceedingJoinPoint joinPoint) throws Throwable {
      MethodSignature methodSignature = (MethodSignature)joinPoint.getSignature();
      Method method = methodSignature.getMethod();
      LinkApiHighestOauth methodAnnotation = (LinkApiHighestOauth)method.getDeclaredAnnotation(LinkApiHighestOauth.class);
      boolean checkFlag = false;
      if (DEFAULT_INTERCEPT_API.contains(method.getName())) {
         checkFlag = true;
      } else if (null != methodAnnotation) {
         checkFlag = true;
      }

      if (!checkFlag) {
         return joinPoint.proceed();
      } else {
         Object[] methodParams = joinPoint.getArgs();
         if (null != methodParams && methodParams.length >= 1) {
            for(int i = 0; i < methodParams.length; ++i) {
               Object param = methodParams[i];
               if (param instanceof BasicModel) {
                  HttpServletRequest request = null;

                  for(int j = 0; j < methodParams.length; ++j) {
                     if (HttpServletRequest.class.isAssignableFrom(methodParams[j].getClass())) {
                        request = (HttpServletRequest)methodParams[j];
                     }
                  }

                  LinkOauthConditionV2 linkOauthConditionV2 = (LinkOauthConditionV2)param.getClass().getDeclaredAnnotation(LinkOauthConditionV2.class);
                  LinkOauthConditionV1 linkOauthConditionV1 = (LinkOauthConditionV1)param.getClass().getDeclaredAnnotation(LinkOauthConditionV1.class);
                  HighestOauthType[] var10000 = new HighestOauthType[]{HighestOauthType.ALL};
                  HighestOauthType[] highestOauthTypes;
                  if (null != linkOauthConditionV2) {
                     highestOauthTypes = linkOauthConditionV2.value();
                  } else {
                     if (null == linkOauthConditionV1) {
                        continue;
                     }

                     highestOauthTypes = linkOauthConditionV1.value();
                  }

                  Map<String, Object> result = new HashMap();
                  String oauth = ((BasicModel)param).getOauth();
                  CoreUser user = UserUtil.getUser();

                  try {
                     boolean noCheck1 = false;
                     String transToAuth = null;
                     if (null != methodAnnotation) {
                        noCheck1 = HigestOauthUtil.conditionProcessResult(methodAnnotation, (BasicModel)param, user);
                        transToAuth = methodAnnotation.transToOauth();
                     }

                     boolean noCheck2 = false;
                     if (null != linkOauthConditionV2) {
                        noCheck2 = HigestOauthUtil.conditionProcessResult(linkOauthConditionV2, (BasicModel)param, user);
                        transToAuth = linkOauthConditionV2.transToOauth();
                     }

                     boolean noCheck3 = false;
                     if (null != linkOauthConditionV1) {
                        noCheck3 = HigestOauthUtil.conditionProcessResult(linkOauthConditionV1, (BasicModel)param, user);
                        transToAuth = linkOauthConditionV1.transToOauth();
                     }

                     if (!noCheck1 && !noCheck2 && !noCheck3) {
                        String openFlag = PropertyUtil.getProperty("openHighestOauthCheck", 0L);
                        if (!StringUtils.isBlank(oauth) && null != user) {
                           SecurityMenuParse.handleHighestOauth(highestOauthTypes, oauth, openFlag, request, param);
                           continue;
                        }

                        if ("LOG".equalsIgnoreCase(openFlag)) {
                           SecurityMenuParse.sendSecurityCheckLog(oauth, request, param, "未传入安全性条件或未登录");
                           return joinPoint.proceed();
                        }

                        result.put("success", false);
                        result.put("result", "未传入安全性条件或未登录");
                        result.put("detailMessage", "未传入安全性条件");
                        result.put("code", "444");
                        return result;
                     }

                     if (StringUtils.isNotBlank(transToAuth)) {
                        ReflectUtil.invokeSetterNew(param, "oauth", transToAuth);
                        methodParams[i] = param;

                        for(int j = 0; j < methodParams.length; ++j) {
                           if (methodParams[j] instanceof QueryParams) {
                              Object queryParams = methodParams[j];
                              ReflectUtil.invokeSetterNew(queryParams, "oauth", transToAuth);
                              methodParams[j] = queryParams;
                           }
                        }
                     }

                     return joinPoint.proceed(methodParams);
                  } catch (BasicServiceException var22) {
                     BasicServiceException e = var22;
                     result.put("success", false);
                     result.put("result", e.getMessage());
                     result.put("detailMessage", e.getDetailMessage());
                     result.put("code", e.getCode());
                     return result;
                  }
               }
            }

            return joinPoint.proceed();
         } else {
            return joinPoint.proceed();
         }
      }
   }
}
